@@ -1,12 +1,10 @@
 # Trains and Updates Ultralytics HUB Models
 
-from .auth import Auth
+from . import AUTH
 from .config import BY_PASS_LOGIN
 from .trainer import Trainer
 from .yolov5_wrapper import verify_install
 
-auth = Auth()
-
 
 def setup_yolo() -> None:
     """Checks if yolov5 exists and if not clones it"""
@@ -15,7 +13,7 @@ def setup_yolo() -> None:
 
 def train_model() -> None:
     """Starts training from next in queue"""
-    trainer = Trainer(None, auth)  # No model so next in train queue is fetched
+    trainer = Trainer(None, AUTH)  # No model so next in train queue is fetched
     if trainer.model is not None:
         trainer.start()
 
@@ -24,9 +22,9 @@ def connect_to_hub(password=False) -> bool:
     """Authenticates user with Ultralytics HUB"""
 
     if password:
-        success = auth.attempt_signin()
+        success = AUTH.attempt_signin()
     else:
-        success = auth.attempt_api_key()
+        success = AUTH.attempt_api_key()
 
     return success
 
@@ -34,8 +32,8 @@ def connect_to_hub(password=False) -> bool:
 def main():
     setup_yolo()
     if BY_PASS_LOGIN:
-        auth.sign_in_with_email_and_password("kalen.michael@ultralytics.com", "7654321")
-        if auth.idToken:
+        AUTH.sign_in_with_email_and_password("kalen.michael@ultralytics.com", "7654321")
+        if AUTH.idToken:
             train_model()
         else:
             print("Incorrect Login Details.")
