@@ -5,7 +5,7 @@ import subprocess
 from .config import REPO_URL, REPO_BRANCH, ENVIRONMENT
 
 
-def installDependencies():
+def install_dependencies():
     print('Installing YOLOv5 🚀 requirements...', end=" ")
     if ENVIRONMENT == 'development':
         subprocess.call(['pip', 'install', '-r', 'yolov5/requirements.txt'])
@@ -16,7 +16,7 @@ def installDependencies():
     print('Done')
 
 
-def verifyInstall():
+def verify_install():
     """
     Check that YOLOv5 is on the system and clone if not found
     """
@@ -24,17 +24,16 @@ def verifyInstall():
         from git import Repo
         try:
             print(f"Cloning YOLOv5 🚀 from {REPO_URL}...", end=" ")
-            Repo.clone_from(REPO_URL, "yolov5", branch=REPO_BRANCH
-                            )  # Temp solution while waiting on pull request
+            Repo.clone_from(REPO_URL, "yolov5", branch=REPO_BRANCH)  # Temp solution while waiting on pull request
             print("Done")
-            installDependencies()
+            install_dependencies()
 
         except Exception as e:
             print("Failed")
             print('Error: ' + str(e))
 
 
-verifyInstall()
+verify_install()
 
 
 class YOLOv5Wrapper:
@@ -61,7 +60,8 @@ class YOLOv5Wrapper:
         _train.main(opt, callback_handler)
         # sys.stdout = sys.__stdout__ # Restore output
 
-    def newCallbackHandler():
+    @staticmethod
+    def new_callback_handler():
         """Returns a YOLOv5 callback handler"""
         _callback_handler = importlib.import_module("yolov5.utils.callbacks")
         return _callback_handler.Callbacks()
